# A polytope perspective

This section is there to support the paper [*Online Stochastic Matching: A Polytope Perspective*][paper].

Its goal is to demonstrate how the results from the paper above can be obtained using the [stochasting_matching package][package].

It contains in particular:

- Demonstration of the use of the [package] for theoretical description (graph categorization, etc...);
- the production of all simulation-based results from the [paper].

:::{warning}
This section is NOT intended to be self-contained. Please refer to the [paper] for context and explanations.
:::

:::{toctree}
first_steps
polytope
simulations
:::


[paper]: https://hal.archives-ouvertes.fr/hal-03502084
[package]: https://balouf.github.io/stochastic_matching/index.html
